@@ -4,7 +4,7 @@ Created on 2020-11-9
 
 @author: zhys513(254851907@qq.com)
 '''
-from opspipe.reg.spliter import regularExtrator 
+from opspipe.reg.spliter import RegularExtrator 
 from unittest import TestCase 
 import unittest
 
@@ -13,7 +13,7 @@ text = '急寻特朗普，男孩，于2018年11月27号11时在陕西省安康
 class TestMain(TestCase):
     
     def test_seg_generator(self): 
-        ex = regularExtrator(text) 
+        ex = RegularExtrator(text) 
         print(ex.clear_txt())
         print(ex.split_txt(r'[：]'))
         print(ex.split_list())
