@@ -18,11 +18,14 @@ class RegularExtrator(cre):
         self.data_list = data_list_out
         return self.data_list
     
-    def split_txt(self,pattern_split= r'[，。；]'): 
-        data_list_out = re.split(pattern_split, self.text) 
-        self.data_list = data_list_out
+    def split_txt(self,pattern_split= r'[，。；]',retain = False): 
+        sentences = re.split(pattern_split, self.text) 
+        sentences.append("")
+        if retain :
+            sentences = ["".join(i) for i in zip(sentences[0::2],sentences[1::2])]
+        self.data_list = sentences
         return self.data_list
-
+    
     def seg_generator(self,seg_len, seg_backoff=0):   # 滑窗算法
         data_list_out = []
         iterables = (self.text, )
