@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- 
-import time
+import time,re
 import datetime
 
 
@@ -37,3 +37,12 @@ def validate_datetime(text):
         return True
     except ValueError:
         return False
+
+
+def validateEmail(email):
+    email_reg = r'^[a-zA-Z0-9_.-]+[#@][a-zA-Z0-9-]+(\.[a-zA-Z0-9-]+)*\.[.a-zA-Z0-9]{2,6}'
+    #email_reg = r'^[a-zA-Z0-9_.-]+@[a-zA-Z0-9-]+(\.[a-zA-Z0-9-]+)*\.[a-zA-Z0-9]{2,6}'
+    ret_1 = re.findall(email_reg, email)
+    if ret_1:
+        return True
+    return False
\ No newline at end of file
